<?php
namespace OrganizationsManagement\Controller;
use OrganizationsManagement\Util\Messages;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource;
use OrganizationsManagement\Service;

class Table extends Simple
{
    /** @var Service\Table $serviceTable */
    protected $serviceTable;

    public function __construct(Service\Table $serviceTable){
        $this->serviceTable = $serviceTable;
    }

    public function getTables(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $page       = $request->getFilterCriteria()->getPage();
            $pageSize   = $request->getFilterCriteria()->getPageSize();
            $conditions = $request->getFilterCriteria()->getConditions();
            $tables     = $this->serviceTable->getTables($conditions, $page, $pageSize);
            $response->addDataSet(new DataSource\DataSet('tables', $tables));
        } catch(\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveTables(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $row              = $request->getDataSet()->getRows()[0];
            $tableName        = $row['TABLE_NAME'];
            $tableActive      = $row['ACTIVE'];
            $tableSequential  = $row['SEQUENTIAL'];
            $tableDescription = $row['DESCRIPTION'];
            $this->serviceTable->saveTable($tableName, $tableActive, $tableDescription, $tableSequential);
            $response->addMessage(new DTO\Response\Message(Messages::SUC_SAVED));
        } catch(\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function getAllTables(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $page       = $request->getFilterCriteria()->getPage();
            $pageSize   = $request->getFilterCriteria()->getPageSize();
            $conditions = $request->getFilterCriteria()->getConditions();
            $allTables  = $this->serviceTable->getAllTables($conditions, $page, $pageSize);
            $response->addDataSet(new DataSource\DataSet('allTables', $allTables));
        } catch(\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function deleteTable(DTO\Request\Row $request, DTO\Response $response){
        try {
            $row        = $request->getRow();
            $tableName  = $row['TABLE_NAME'];
            $this->serviceTable->deleteTable($tableName);
        } catch (\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
}